﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APU101
// Target Platform : Windows, .NET Framework, C#
// Date            : Auguts 2017
// Version         : 1.0
//*****************************************************************************
using System;
using System.IO;

namespace APU101_sample
{
	public static class Files
	{
		//#########################################################################
		//  Name      : file_write_header
		//  Function  : write header to the text file
		//  Arguments :
		//      in pName    : file name
		//      in now_time : actual measurement time(msec)
		//      in in_cps   : input count rate(cps)
		//      in th_cps   : throughput count rate(cps)
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_header(string pName, uint now_time, uint in_cps, uint th_cps)
		{
			try {
				// open file(create)
				StreamWriter writer = File.CreateText(pName);

				// write header information
				writer.WriteLine("[header]");
				writer.WriteLine("Real time(s), {0}", now_time/1000);
				writer.WriteLine("Input rate(cps), {0}", in_cps);
				writer.WriteLine("Throughput rate(cps), {0}", th_cps);

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(0);
		}


		//#########################################################################
		//  Name      : file_write_data
		//  Function  : write data to the text file
		//  Arguments :
		//      in pName : file name
		//      in nbyte : size of the data(byte)
		//      in pBuff : pointer to the data buffer
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_data(string pName, int nbyte, byte[] pBuff)
		{
			int i;
			int unit = nbyte;

			try {
				// open file(append)
				StreamWriter writer = File.AppendText(pName);

				writer.WriteLine("[data]");

				// write data in unit of unsigned int
				unit = nbyte / sizeof(uint);
				for (i = 0; i < unit; i++) {
					writer.WriteLine( BitConverter.ToUInt32(pBuff, i*4) );
				}

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(i);
		}

	} // end of class
} // end of namespace

